import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

/// Default App Button
class AppButton extends StatelessWidget {
  final Function? onTap;
  final String? text;
  final double? width;
  final Color? color;
  final Color? textColor;
  final Color? disabledColor;
  final Color? focusColor;
  final Color? hoverColor;
  final Color? splashColor;
  final EdgeInsetsGeometry? padding;
  final TextStyle? textStyle;
  final ShapeBorder? shapeBorder;
  final Widget? child;
  final double? elevation;
  final double? height;
  final bool? enabled;

  AppButton({
    this.onTap,
    this.text,
    this.width,
    this.color,
    this.textColor,
    this.padding,
    this.textStyle,
    this.shapeBorder,
    this.child,
    this.elevation,
    this.enabled,
    this.height,
    this.disabledColor,
    this.focusColor,
    this.hoverColor,
    this.splashColor,
  });

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
      minWidth: width,
      padding: padding ?? EdgeInsets.symmetric(vertical: 14, horizontal: 16),
      onPressed:
          enabled.validate(value: true) ? onTap as void Function()? : null,
      color: color ?? appButtonBackgroundColorGlobal,
      child: child ??
          Text(
            text.validate(),
            style: textStyle ??
                boldTextStyle(
                    color: textColor ?? defaultAppButtonTextColorGlobal),
          ),
      shape: shapeBorder ?? defaultAppButtonShapeBorder,
      elevation: elevation ?? defaultAppButtonElevation,
      animationDuration: Duration(milliseconds: 300),
      height: height,
      disabledColor: disabledColor,
      focusColor: focusColor,
      hoverColor: hoverColor,
      splashColor: splashColor,
    );
  }
}
