import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

typedef void RatingChangeCallback(double rating);

class RatingBarWidget extends StatelessWidget {
  final int itemCount;
  final double initialRating;
  final Color? itemColor;
  final IconData? filledIcon;
  final IconData? emptyIcon;
  final IconData? halfFilledIcon;
  final double itemSize;
  final RatingChangeCallback? onRatingChanged;

  RatingBarWidget({
    this.itemCount = 5,
    this.initialRating = .0,
    this.onRatingChanged,
    this.itemColor = Colors.yellow,
    this.filledIcon,
    this.emptyIcon,
    this.halfFilledIcon,
    this.itemSize = 35,
  });

  IconData? getIcon(double? rating, int? index) {
    IconData icon;
    if (index! >= rating!) {
      icon = emptyIcon == null ? Icons.star_border : emptyIcon as IconData;
    } else if (index > rating - 1 && index < rating) {
      icon =
          halfFilledIcon == null ? Icons.star_half : halfFilledIcon as IconData;
    } else {
      icon = filledIcon == null ? Icons.star : filledIcon as IconData;
    }

    return icon;
  }

  Color? getColor(double rating, int index) {
    Color color;
    if (index >= rating) {
      color = viewLineColor;
    } else if (index > rating - 1 && index < rating) {
      color = itemColor!;
    } else {
      color = itemColor!;
    }

    return color;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      scrollDirection: Axis.horizontal,
      child: Row(
        children: List.generate(
          itemCount,
          (index) => GestureDetector(
            onHorizontalDragUpdate: (dragDetails) {
              Offset _pos = dragDetails.localPosition;

              var localRating = _pos.dx / itemSize;

              if (localRating > itemCount + 0.5) {
                localRating = itemCount.toDouble();
              }
              if (localRating < 0) {
                localRating = 0.0;
              }

              if (this.onRatingChanged != null) onRatingChanged!(localRating);
            },
            onTap: onRatingChanged == null
                ? null
                : () => onRatingChanged!(index + 1.0),
            child: Icon(
              getIcon(initialRating, index),
              color: getColor(initialRating, index),
              size: itemSize,
            ),
          ),
        ),
      ),
    );
  }
}
